==> CFEngine_Enterprise_vagrant_quickstart-3.21.8-1.tar.gz: var/cfengine/share/GUI/application/modules/advancedreports/views/partials/elements/_resultPageBtn.php <==
<?php if ($buttonPosition == 'bottom') echo

'<div ng-if="is_own != 1" class="user_notification user_notification_warning">
    <span ng-if="can_edit == 1">This is not your own report. You can edit it because you have admin role.</span>
</div>'

;?>

<div class="buttons"  ng-show="show_buttons == 1"  <?php if ($buttonPosition == 'top') echo ' style="border-top:none;padding-top:0;"'; ?>>
    <p class="pull-left">
        <button class="btn margin-left_8" ng-show="showDismissHostButton"  ng-click="dismissSelectedHosts()">Dismiss selected hosts</button>
    <?php if (!isset($showEdit) || $showEdit !== false) { ?>
        <span ng-if="can_edit == 1 && !SQL.ruleId">
            <button ng-if="!deleteTableView" class="btn btn-large" ng-click="editReport()" ng-show="!$parent.isInventory">Edit report</button>
        </span>

        <button class="btn margin-left_8" ng-if="deleteTableView" ng-show="showdDeleteHostButton"  ng-click="deleteSeletedHosts()">Delete selected hosts</button>
    <?php } ?>
        <button ng-if="is_own != 1" class="btn btn-large" ng-click="cleanStoredScope(); setCurrentReportData(reportId, savedSearchName, savedSearchCategory.input); modalWindow.open('copySearchModal', this)">Copy</button>
    </p>
    <p class="pull-right">
        <button ng-if="(is_own == 1 || is_subscribed == 1) && !isChanges && !SQL.ruleId" class="schedule_report margin-left_8 btn btn-secondary" ng-click="scheduleReport()">Schedule report</button>
        <button id="save_report" ng-if="is_own == 1  && !SQL.ruleId" class="btn margin-left_8 btn-secondary" ng-click="modalWindow.open('saveSearchModal', this)">Save</button>

        <span ng-if="is_own != 1">
            <button  ng-if="can_subscribe == 1 && is_subscribed == 0" class="btn margin-left_8 btn-large" ng-click="subscribe(reportId)">Subscribe</button>
            <button  ng-if="can_subscribe == 1 && is_subscribed == 1" class="btn margin-left_8 btn-large" ng-click="unsubscribe(reportId)">Unsubscribe</button>
        </span>
         <?php  $this->load->view('/partials/_download_report_btn'); ?>
    </p>
</div>
<?php if ($buttonPosition == 'top') echo

'<div ng-if="is_own != 1" style="font-size:12px; color:red; margin-bottom:20px;margin-top:-20px;">
    <span ng-if="can_edit == 1">This is not your own report. You can edit it because you have admin role.</span>
</div>'
;?>

 <script type="text/ng-template" id="deleteHostConfirmModal.html">
     <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" ng-click="closeHostDeleteConfirmDialog()" ><i class="bi bi-x"></i></button>
        <h1>
            Remove host<span ng-if="selectedKeysForDelete.length>1">s</span>?
        </h1>
    </div>
    <div class="modal-body">
        <div ng-if="!deleteHostKeyMessage.message"><?php echo $this->lang->line('host_delete_confirm'); ?></div>
        <div ng-if="deleteHostKeyMessage.type" class="alert" ng-class="deleteHostKeyMessage.type">{{deleteHostKeyMessage.message}}</div>
    </div>
    <div class="modal-footer">
        <button class="btn btn-large" ng-click="closeHostDeleteConfirmDialog()">Close</button>
        <button ng-if="showDeleteButton" class="btn btn-primary" ng-click="deleteConfirmedHosts()">Remove</button>
    </div>
</script>

==> CFEngine_Enterprise_vagrant_quickstart-3.24.4a-1.tar.gz: var/cfengine/share/GUI/application/modules/advancedreports/views/partials/elements/_resultPageBtn.php <==
<?php if ($buttonPosition == 'bottom') echo

'<div ng-if="is_own != 1" class="user_notification user_notification_warning">
    <span ng-if="can_edit == 1">This is not your own report. You can edit it because you have admin role.</span>
</div>'

;?>

<div class="buttons"  ng-show="show_buttons == 1"  <?php if ($buttonPosition == 'top') echo ' style="border-top:none;padding-top:0;"'; ?>>
    <p class="pull-left">
        <button class="btn margin-left_8" ng-show="showDismissHostButton"  ng-click="dismissSelectedHosts()">Dismiss selected hosts</button>
    <?php if (!isset($showEdit) || $showEdit !== false) { ?>
        <span ng-if="can_edit == 1 && !SQL.ruleId">
            <button id="edit_report" ng-if="!deleteTableView" class="btn btn-large" ng-click="editReport()" ng-show="!$parent.isInventory">Edit report</button>
        </span>

        <button class="btn margin-left_8" ng-if="deleteTableView" ng-show="showdDeleteHostButton"  ng-click="deleteSeletedHosts()">Delete selected hosts</button>
    <?php } ?>
        <button ng-if="is_own != 1" class="btn btn-large" ng-click="cleanStoredScope(); setCurrentReportData(reportId, savedSearchName, savedSearchCategory.input); modalWindow.open('copySearchModal', this)">Copy</button>
    </p>
    <p class="pull-right">
        <button ng-if="can_edit_columns == 1" class="btn btn-secondary no-border" ng-click="openInsertColumnDialog()"><i class="bi bi-layout-three-columns"></i>
            Columns</button>
        <button ng-if="(is_own == 1 || is_subscribed == 1) && !isChanges && !SQL.ruleId" class="schedule_report margin-left_8 btn btn-secondary" ng-click="scheduleReport()">Schedule</button>
        <button id="save_report" ng-if="is_own == 1  && !SQL.ruleId" class="btn margin-left_8 btn-secondary" ng-click="modalWindow.open('saveSearchModal', this)">Save</button>

        <span ng-if="is_own != 1">
            <button  ng-if="can_subscribe == 1 && is_subscribed == 0" class="btn margin-left_8 btn-large" ng-click="subscribe(reportId)">Subscribe</button>
            <button  ng-if="can_subscribe == 1 && is_subscribed == 1" class="btn margin-left_8 btn-large" ng-click="unsubscribe(reportId)">Unsubscribe</button>
        </span>
         <?php  $this->load->view('/partials/_download_report_btn'); ?>
    </p>
</div>
<?php if ($buttonPosition == 'top') echo

'<div ng-if="is_own != 1" style="font-size:12px; color:red; margin-bottom:20px;margin-top:-20px;">
    <span ng-if="can_edit == 1">This is not your own report. You can edit it because you have admin role.</span>
</div>'
;?>

 <script type="text/ng-template" id="deleteHostConfirmModal.html">
     <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" ng-click="closeHostDeleteConfirmDialog()" ><i class="bi bi-x"></i></button>
        <h1>
            Remove host<span ng-if="selectedKeysForDelete.length>1">s</span>?
        </h1>
    </div>
    <div class="modal-body">
        <div ng-if="!deleteHostKeyMessage.message"><?php echo $this->lang->line('host_delete_confirm'); ?></div>
        <div ng-if="deleteHostKeyMessage.type" class="alert" ng-class="deleteHostKeyMessage.type">{{deleteHostKeyMessage.message}}</div>
    </div>
    <div class="modal-footer">
        <button class="btn btn-large" ng-click="closeHostDeleteConfirmDialog()">Close</button>
        <button ng-if="showDeleteButton" class="btn btn-primary" ng-click="deleteConfirmedHosts()">Remove</button>
    </div>
</script>
